==> advanced-systemui_0.5.8.tar.gz: advanced-systemui-0.5.8/config.h <==
#include <gconf/gconf-client.h>

extern const char *conf_max_brightness;
extern const char *conf_brightness;
extern const char *conf_dim_timeout;
extern const char *conf_blank_timeout;
extern const char *conf_volume;
extern const char *conf_system_alert_volume;
extern const char *conf_keypad_volume;
extern const char *conf_touchscreen_volume;
extern const char *conf_screen_autolock1;
extern const char *conf_screen_autolock2;
extern const char *conf_screen_stayslit1;
extern const char *conf_screen_stayslit2;

extern const char *conf_brightness_level;
extern const char *conf_theme;
extern const char *conf_ssh_server;
extern const char *conf_battery_usage;
extern const char *conf_screenshot_delay;
extern const char *conf_original_screen_autolock;
extern const char *conf_original_screen_stayslit;

extern const char *conf_alarm_open;
extern const char *conf_alarm_tklock;
extern const char *conf_alarm_cb_service;
extern const char *conf_alarm_cb_path;
extern const char *conf_alarm_cb_iface;
extern const char *conf_alarm_cb_method;
extern const char *conf_alarm_description;
extern const char *conf_alarm_sound;
extern const char *conf_alarm_mode;
extern const char *conf_alarm_timestamp;

extern GConfClient *gconf_client;

// battery
extern unsigned cfg_battery_idle_time, cfg_memory_format, cfg_swap_format, cfg_temperature_F, cfg_history_days, cfg_track_usage_events;
// clock
extern unsigned cfg_clock_24h, cfg_clock_ampm;
extern unsigned cfg_popup_duration, cfg_popup_onmap, cfg_popup_fullscreen, cfg_popup_cooldown, cfg_popup_noasui;
// brightness
extern unsigned cfg_brightness_enhanced, cfg_brightness_allow_zero;
// BRV keys
extern unsigned cfg_buttons_rotate, cfg_buttons_brightness, cfg_buttons_brightness_step, cfg_buttons_volume, cfg_buttons_volume_step;
// button modes
extern unsigned cfg_double_tap, cfg_lock_and_close, cfg_rotate_and_close, cfg_split_lock_buttons;
extern unsigned cfg_buttons_dpad_short, cfg_buttons_dpad_long, cfg_buttons_lock1_short, cfg_buttons_lock1_long, cfg_buttons_lock2_short, cfg_buttons_lock2_long;
// power button
extern unsigned cfg_power_enable_double;
extern unsigned cfg_power_action_single, cfg_power_action_double, cfg_power_longpress_shutdown, cfg_power_blanks_when_locked, cfg_power_unlock_key;
// device lock
extern unsigned cfg_secure_button, cfg_secure_action, cfg_secure_power_action_single, cfg_secure_power_action_double;
// user interface
extern unsigned cfg_tkactive_notifications, cfg_service_size_unit, cfg_short_tap_markers, cfg_start_visible, cfg_threshold_black, cfg_threshold_white;
// alarm
extern unsigned cfg_alarm_duration, cfg_alarm_volume_min, cfg_alarm_volume_max, cfg_alarm_volume_step;

// state
extern unsigned cfg_theme, cfg_ssh_server, cfg_battery_usage, cfg_screenshot_delay;
extern float cfg_power_long_delay, cfg_power_double_delay;

#define CFG_BUTTONS_ZOOM 1
#define CFG_BUTTONS_UD 2
#define CFG_BUTTONS_LR 3

enum { POWER_ACTION_NONE, POWER_ACTION_LOCK, POWER_ACTION_LOCKBLANK, POWER_ACTION_BLANK, POWER_ACTION_OPEN, POWER_ACTION_OPENCLOSE };

#define MIN_SCREENSHOT_DELAY 1
#define MAX_SCREENSHOT_DELAY 20

//////////////////////////////////////////////////////////////////////////

typedef enum e_widget_size { EMPTY_CELL, FULL_WIDGET, HALF_WIDGET } e_widget_size;

typedef struct s_widget {
	const char *name;
	const char *conf;
	e_widget_size size;
	void (*draw)( unsigned force, int x, int y );
	void (*click)( );
	unsigned cell;
} s_widget;

typedef struct s_widget_cell {
	e_widget_size size;
	s_widget *left;
	s_widget *right;
} s_widget_cell;

#define MAX_WIDGET_CELLS 20
extern s_widget_cell landscape_cells[MAX_WIDGET_CELLS];
extern s_widget_cell portrait_cells[MAX_WIDGET_CELLS];

//////////////////////////////////////////////////////////////////////////

typedef struct s_button {
	const char *name;
	const char *conf;
	void (*draw)( unsigned force, int x, int y );
	void (*click)( );
	unsigned cell;
} s_button;

#define MAX_BUTTON_CELLS 20
extern s_button *button_cells[MAX_BUTTON_CELLS];

//////////////////////////////////////////////////////////////////////////

void config_init( );
void config_reload( );

#define conf_get_bool(key) gconf_client_get_bool(gconf_client, key, (GError **)NULL)
#define conf_get_int(key) gconf_client_get_int(gconf_client, key, (GError **)NULL)
#define conf_get_float(key) gconf_client_get_float(gconf_client, key, (GError **)NULL)
#define conf_get_string(key) gconf_client_get_string(gconf_client, key, (GError **)NULL)

#define conf_set_bool(key, value) gconf_client_set_bool(gconf_client, key, value, (GError **)NULL)
#define conf_set_int(key, value) gconf_client_set_int(gconf_client, key, value, (GError **)NULL)
#define conf_set_float(key, value) gconf_client_set_float(gconf_client, key, value, (GError **)NULL)
#define conf_set_string(key, value) gconf_client_set_string(gconf_client, key, value, (GError **)NULL)

#define conf_get_screen_autolock_value() gconf_client_get_bool(gconf_client, conf_screen_autolock1, (GError **)NULL)
#define conf_get_screen_stayslit_value() gconf_client_get_bool(gconf_client, conf_screen_stayslit1, (GError **)NULL)
void conf_set_screen_autolock_value( unsigned value );
void conf_set_screen_stayslit_value( unsigned value );

void config_save_widget( s_widget *widget, unsigned cell, unsigned subcell, unsigned landscape );

#define conf_get_screen_blank_offset() \
	gconf_client_get_int(gconf_client, conf_blank_timeout, (GError **)NULL) - gconf_client_get_int(gconf_client, conf_dim_timeout, (GError **)NULL)

==> advanced-systemui_0.5.9.tar.gz: advanced-systemui-0.5.9/config.h <==
#include <gconf/gconf-client.h>

extern const char *conf_max_brightness;
extern const char *conf_brightness;
extern const char *conf_dim_timeout;
extern const char *conf_blank_timeout;
extern const char *conf_volume;
extern const char *conf_system_alert_volume;
extern const char *conf_keypad_volume;
extern const char *conf_touchscreen_volume;
extern const char *conf_screen_autolock1;
extern const char *conf_screen_autolock2;
extern const char *conf_screen_stayslit1;
extern const char *conf_screen_stayslit2;

extern const char *conf_ignore_master_volume;
extern const char *conf_brightness_level;
extern const char *conf_theme;
extern const char *conf_ssh_server;
extern const char *conf_battery_usage;
extern const char *conf_screenshot_delay;
extern const char *conf_original_screen_autolock;
extern const char *conf_original_screen_stayslit;

extern const char *conf_alarm_open;
extern const char *conf_alarm_tklock;
extern const char *conf_alarm_cb_service;
extern const char *conf_alarm_cb_path;
extern const char *conf_alarm_cb_iface;
extern const char *conf_alarm_cb_method;
extern const char *conf_alarm_description;
extern const char *conf_alarm_sound;
extern const char *conf_alarm_mode;
extern const char *conf_alarm_timestamp;

extern GConfClient *gconf_client;

// statusbar
//extern unsigned cfg_statusbar_battery_enable, cfg_statusbar_wifi_enable, cfg_statusbar_bluetooth_enable, cfg_statusbar_drain_enable, cfg_statusbar_cpu_enable;

// battery
extern unsigned cfg_battery_idle_time, cfg_memory_format, cfg_swap_format, cfg_temperature_F, cfg_history_days, cfg_track_usage_events;
// clock
extern unsigned cfg_clock_24h, cfg_clock_ampm;
extern unsigned cfg_popup_duration, cfg_popup_onmap, cfg_popup_fullscreen, cfg_popup_cooldown, cfg_popup_noasui;
// brightness
extern unsigned cfg_brightness_enhanced, cfg_brightness_allow_zero;
// WiFi
extern unsigned cfg_wifi_disconnect_fix;
// BRV keys
extern unsigned cfg_buttons_rotate, cfg_buttons_brightness, cfg_buttons_brightness_step, cfg_buttons_volume, cfg_buttons_volume_step;
// button modes
extern unsigned cfg_double_tap, cfg_lock_and_close, cfg_rotate_and_close, cfg_split_lock_buttons;
extern unsigned cfg_buttons_dpad_short, cfg_buttons_dpad_long, cfg_buttons_lock1_short, cfg_buttons_lock1_long, cfg_buttons_lock2_short, cfg_buttons_lock2_long;
// power button
extern unsigned cfg_power_enable_double;
extern unsigned cfg_power_action_single, cfg_power_action_double, cfg_power_longpress_shutdown, cfg_power_blanks_when_locked, cfg_power_unlock_key;
// device lock
extern unsigned cfg_secure_button, cfg_secure_action, cfg_secure_power_action_single, cfg_secure_power_action_double;
// user interface
extern unsigned cfg_tkactive_notifications, cfg_service_size_unit, cfg_short_tap_markers, cfg_start_visible, cfg_threshold_black, cfg_threshold_white;
extern char *cfg_theme_file_black, *cfg_theme_file_white;
extern unsigned cfg_window_slide_unmap, cfg_window_slide_map;
// alarm
extern unsigned cfg_alarm_duration, cfg_alarm_volume_min, cfg_alarm_volume_max, cfg_alarm_volume_step;

// state
extern unsigned cfg_theme, cfg_ssh_server, cfg_battery_usage, cfg_screenshot_delay;
extern float cfg_power_long_delay, cfg_power_double_delay;

#define CFG_BUTTONS_ZOOM 1
#define CFG_BUTTONS_UD 2
#define CFG_BUTTONS_LR 3

enum { POWER_ACTION_NONE, POWER_ACTION_LOCK, POWER_ACTION_LOCKBLANK, POWER_ACTION_BLANK, POWER_ACTION_OPEN, POWER_ACTION_OPENCLOSE };

#define MIN_SCREENSHOT_DELAY 1
#define MAX_SCREENSHOT_DELAY 20

//////////////////////////////////////////////////////////////////////////

typedef enum e_widget_size { EMPTY_CELL, FULL_WIDGET, HALF_WIDGET } e_widget_size;

typedef struct s_widget {
	const char *name;
	const char *conf;
	e_widget_size size;
	void (*draw)( unsigned force, int x, int y );
	void (*click)( );
	unsigned cell;
} s_widget;

typedef struct s_widget_cell {
	e_widget_size size;
	s_widget *left;
	s_widget *right;
} s_widget_cell;

#define MAX_WIDGET_CELLS 20
extern s_widget_cell landscape_cells[MAX_WIDGET_CELLS];
extern s_widget_cell portrait_cells[MAX_WIDGET_CELLS];

//////////////////////////////////////////////////////////////////////////

typedef struct s_button {
	const char *name;
	const char *conf;
	void (*draw)( unsigned force, int x, int y );
	void (*click)( );
	unsigned cell;
} s_button;

#define MAX_BUTTON_CELLS 20
extern s_button *button_cells[MAX_BUTTON_CELLS];

//////////////////////////////////////////////////////////////////////////

void config_init( );
void config_reload( );

#define conf_get_bool(key) gconf_client_get_bool(gconf_client, key, (GError **)NULL)
#define conf_get_int(key) gconf_client_get_int(gconf_client, key, (GError **)NULL)
#define conf_get_float(key) gconf_client_get_float(gconf_client, key, (GError **)NULL)
#define conf_get_string(key) gconf_client_get_string(gconf_client, key, (GError **)NULL)

#define conf_set_bool(key, value) gconf_client_set_bool(gconf_client, key, value, (GError **)NULL)
#define conf_set_int(key, value) gconf_client_set_int(gconf_client, key, value, (GError **)NULL)
#define conf_set_float(key, value) gconf_client_set_float(gconf_client, key, value, (GError **)NULL)
#define conf_set_string(key, value) gconf_client_set_string(gconf_client, key, value, (GError **)NULL)

#define conf_get_screen_autolock_value() gconf_client_get_bool(gconf_client, conf_screen_autolock1, (GError **)NULL)
#define conf_get_screen_stayslit_value() gconf_client_get_bool(gconf_client, conf_screen_stayslit1, (GError **)NULL)
void conf_set_screen_autolock_value( unsigned value );
void conf_set_screen_stayslit_value( unsigned value );

void config_save_widget( s_widget *widget, unsigned cell, unsigned subcell, unsigned landscape );

#define conf_get_screen_blank_offset() \
	gconf_client_get_int(gconf_client, conf_blank_timeout, (GError **)NULL) - gconf_client_get_int(gconf_client, conf_dim_timeout, (GError **)NULL)
